.. _index:

==================
Documentation Home
==================

Askbot is an open source Question and Answer (Q&A) forum project inspired by StackOverflow 
and YahooAnswers.

This version of Askbot supports only Django 1.8.

To upgrade, or select version of Askbot working with earlier versions of Django,
please follow `the instructions`_.

It is quick and easy to install and deploy askbot on your site.
Have questions? - please ask
at the forum_ or by email at admin@askbot.org

.. toctree::
   :maxdepth: 1

   Install the software <install>
   Create the database <create-database>
   Create and configure the site files<initial-configuration>
   Initialize the database tables <initialize-database-tables>
   Deploy on a webserver <deployment>
   Upgrades <upgrade>
   Import data (StackExchange & ZenDesk) <import-data>
   Moderation <moderation>
   Appendix A: Maintenance procedures <management-commands>
   Appendix B: Sending email to askbot <sending-email-to-askbot>
   Appendix C: Optional modules <optional-modules>
   Appendix D: Api <api>
   Appendix E: Askbot as reusable Django application <askbot-as-reusable-django-application>
   Appendix F: Customizing skin in askbot <customizing-skin-in-askbot>
   Appendix G: Intranet setup <intranet-setup>
   Appendix H: Language support in Askbot <localization>
   Appendix I: Configuration of text search <text-search>
   Appendix J: Migration from MySQL to PostgreSQL <mysql-to-postgres>
   Footnotes <footnotes>
   Contributors <contributors>
   Changelog <changelog>

Some background information: Askbot is written in Python on top of the Django platform.
Code of Askbot grew out of CNPROG project originally written by 
Mike Chen and Sailing Cai.

.. _Python: http://www.python.org/download/
.. _YahooAnswers: http://answers.yahoo.com/
.. _StackOverflow: http://stackoverflow.com/
.. _Django: http://djangoproject.com
.. _CNPROG: http://cnprog.com
.. _forum: http://askbot.org
.. _`development version`: http://github.com/ASKBOT/askbot-devel
<<<<<<< HEAD
.. _`the instructions`: https://github.com/ASKBOT/askbot-devel/blob/master/askbot/doc/source/upgrade.rst
=======
.. _`upgrade instructions`: https://github.com/ASKBOT/askbot-devel/blob/master/askbot/doc/source/upgrade.rst
>>>>>>> 0.8.x
